@@ -7,7 +7,7 @@ from proteus import config, Model
 class TestModel(TestCase):
 
     def setUp(self):
-        config.set_trytond(':memory:', database_type='sqlite')
+        config.set_trytond(database_type='sqlite')
 
     def test_class_cache(self):
         User1 = Model.get('res.user')
@@ -39,7 +39,7 @@ class TestModel(TestCase):
         admin.create_uid = admin
         admin.create_uid = None
 
-        test = User(write_uid=False)
+        User(write_uid=False)
 
     def test_one2many(self):
         Group = Model.get('res.group')
@@ -241,7 +241,7 @@ class TestModel(TestCase):
         self.assertNotEqual(admin1, None)
         self.assertNotEqual(admin1, False)
 
-        self.failUnlessRaises(NotImplementedError, lambda: admin1 == 1)
+        self.assertRaises(NotImplementedError, lambda: admin1 == 1)
 
     def test_default_set(self):
         User = Model.get('res.user')
@@ -289,6 +289,14 @@ class TestModel(TestCase):
         trigger.on_create = True
         self.assertEqual(trigger.on_time, False)
 
+    def test_on_change_with(self):
+        Attachment = Model.get('ir.attachment')
+
+        attachment = Attachment()
+
+        attachment.description = 'Test'
+        self.assertEqual(attachment.summary, 'Test')
+
     def test_on_change_set(self):
         User = Model.get('res.user')
         Group = Model.get('res.group')
